import 'dart:async';
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_linkify/flutter_linkify.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:likepoint_payment/text_style.dart';
import 'package:likepoint_payment/ui/payment_completed/component/payment_completed_component.dart';
import 'package:likepoint_payment/ui/payment_confirm/component/payment_confirm_component.dart';
import 'package:url_launcher/url_launcher.dart';

class PaymentCompleted extends StatefulWidget {
  PaymentCompleted({Key key, this.title}) : super(key: key);

  final String title;

  @override
  _PaymentCompleted createState() => _PaymentCompleted();
}

class _PaymentCompleted extends State<PaymentCompleted> {
  TextEditingController nameController = TextEditingController();

  bool statusOTP = false;

  @override
  Widget build(BuildContext context) {
    ScreenUtil.init(context,
        designSize: Size(1080, 2340), allowFontScaling: false);
    return Scaffold(
      body: Padding(
        padding: EdgeInsets.symmetric(horizontal: 100.w),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: <Widget>[
            SizedBox(height: 130.h),
            GestureDetector(
              onTap: () => Navigator.of(context).pop(true),
              child: Align(
                alignment: Alignment.centerLeft,
                child: Icon(
                  Icons.clear,
                  size: 60.h,
                  color: Colors.black,
                ),
              ),
            ),
            SizedBox(height: 300.h),
            PaymentConfirmComponent.iconLikePoint(),
            SizedBox(height: 100.h),
            PaymentCompletedComponent.textLine1(
                context: context, text: 'ขอบคุณ!'),
            SizedBox(height: 50.h),
            PaymentCompletedComponent.textLine2(
                context: context,
                text: 'คุณได้ทำการชำระ LIKE POINT เรียบร้อยแล้ว'),
            SizedBox(height: 100.h),
          ],
        ),
      ),
    );
  }

  Future<void> _onOpen(LinkableElement link) async {
    print(link.url);
    if (await canLaunch(link.url)) {
      await launch(link.url);
    } else {
      throw 'Could not launch $link';
    }
  }

  Widget detail({String textTitle, String textDetail}) {
    return Container(
      child: Row(
        children: [
          Expanded(
            child: Align(
              alignment: Alignment.centerRight,
              child: PaymentConfirmComponent.textLine3(
                  context: context, text: textTitle),
            ),
          ),
          SizedBox(width: 20.w),
          Expanded(
            child: Align(
              alignment: Alignment.centerLeft,
              child: PaymentConfirmComponent.textLine4(
                  context: context, text: textDetail),
            ),
          ),
        ],
      ),
    );
  }

  Widget cardOTP() {
    return Container(
        decoration: BoxDecoration(border: Border.all(color: Colors.black12)),
        height: 300.h,
        width: MediaQuery.of(context).size.width,
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            PaymentConfirmComponent.textLine3(
                context: context,
                text: 'กรุณาระบุรหัสรักษาความปลอดภัย SMS-OTP ที่ได้รับ'),
            SizedBox(height: 20.h),
            Container(
                height: 80.h,
                width: 250.w,
                child: TextField(
                  controller: nameController,
                  keyboardType: TextInputType.number,
                  textAlign: TextAlign.center,
                  textAlignVertical: TextAlignVertical.center,
                  inputFormatters: <TextInputFormatter>[
                    FilteringTextInputFormatter.digitsOnly,
                    LengthLimitingTextInputFormatter(6),
                  ], // Only numbers
                  style: TextStyleCustom.textStyleNG30(context),
                  decoration: InputDecoration(
                    isDense: true,
                    border: OutlineInputBorder(),
                    contentPadding: EdgeInsets.only(top: 20.h, bottom: 20.h),
                  ),
                )),
            SizedBox(height: 20.h),
          ],
        ));
  }

  Widget buttonAction() {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceAround,
      children: [
        SizedBox(
          height: 100.h,
          child: RaisedButton(
            child: Text(
              "ตกลง",
              style: TextStyleCustom.textStyleNG35(context),
            ),
            onPressed: () => {},
            color: Colors.blue[300],
            textColor: Colors.black,
            // padding: EdgeInsets.all(3.0),
            shape: RoundedRectangleBorder(
              borderRadius: new BorderRadius.circular(5.0),
              side: BorderSide(color: Colors.black12),
            ),
          ),
        ),
      ],
    );
  }
}
